Accesses the meta slot, which holds flags such as whether the
table is a full peptide * sample grid, the available outcome columns, etc.
Examples
pd <- load_example_data()
meta <- get_meta(pd)
Accesses the meta slot, which holds flags such as whether the
table is a full peptide * sample grid, the available outcome columns, etc.
pd <- load_example_data()
meta <- get_meta(pd)